@@ -18,8 +18,8 @@ def send_group_processors(group, **kwargs):
     for inst in plugins.all():
         try:
             inst.post_process(group=group, **kwargs)
-        except:
+        except Exception, e:
             transaction.rollback_unless_managed(using=group._state.db)
             logger = logging.getLogger('sentry.plugins')
-            logger.exception('Error processing post_process() on %r', inst.__class__)
+            logger.exception('Error processing post_process() on %r: %s', inst.__class__, e)
 
